<?php
/**
 * Class WAO Segundo email settings file.
 * (linea 62 se valida si es multisite)
 * @package waosegundoemail\Emails 
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
if ( ! class_exists( 'wao_segundo_correo_config', false ) ) :

	class SegundoEmailSettings {
		var $message ="";
		public function __construct() {
			add_action('admin_menu', array($this, 'add_segundoemail_menu')); 
			add_action('admin_init', array($this, 'register_segundoemail_settings'));
			add_action('woocommerce_admin_order_data_after_billing_address', array($this, 'correo2enviado')); //Inserta un testigo en pagina order
		}

		public function add_segundoemail_menu() {
//                        title		             menutit	     	   capacidad	        slug		funcion			 			logo 	   pos
//	add_menu_page('WAO Marketing system', 'WAOLM Marketing System', 'manage_options','waoem_config','waoem_ordenes_no_completadas',$waoem_logo, 14);

			add_menu_page(
				'Alternate Email Settings',
				'Alternate Email',
				'manage_options',
				'segundoemail_settings',
				array($this, 'render_segundoemail_settings_page'),
				'dashicons-email',
				9
			);
		}

		public function render_segundoemail_settings_page() {
			?>
			<div class="wrap">
				<h2>Alternate email configuration.</h2>
				<p>This configuration applies to sending the completed order email from another SMTP</p>
				<form method="post" action="options.php">
					<?php settings_fields('segundoemail_options_group'); ?>
					<?php do_settings_sections('segundoemail_settings'); ?>
					<?php submit_button(); ?>
				</form>
			</div>
			<?php
		}

		public function register_segundoemail_settings() {
			register_setting('segundoemail_options_group', 'segundoemail_options', array($this, 'sanitize_segundoemail_options'));

			add_settings_section('segundoemail_section', '2do SMTP configuration ', array($this, 'segundoemail_section_callback'), 'segundoemail_settings');

			add_settings_field('activo', 'Activate', array($this, 'activo_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('host', 'Host', array($this, 'host_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('username', 'Username', array($this, 'username_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('password', 'Password', array($this, 'password_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('smtptipo', 'SMTP Type', array($this, 'smtptipo_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('port', 'Port', array($this, 'port_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			//add_settings_field('testbutton', 'Test Configuration', array($this, 'test_button_callback'), 'segundoemail_settings', 'segundoemail_section');
			if(is_multisite()){
				add_settings_field('maestro', 'Master Config', array($this, 'maestro_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			}
		}

		public function segundoemail_section_callback(){
			echo $this->message;
		}

		public function sanitize_segundoemail_options($input) {
			$sanitized_input = array();

			if (isset($input['activo'])) {
				$sanitized_input['activo'] = sanitize_text_field($input['activo']);
			}

			if (isset($input['host'])) {
				$sanitized_input['host'] = sanitize_text_field($input['host']);
			}

			if (isset($input['username'])) {
				$sanitized_input['username'] = sanitize_text_field($input['username']);
			}

			if (isset($input['password'])) {
				$sanitized_input['password'] = sanitize_text_field($input['password']);
			}

			if (isset($input['smtptipo'])) {
				$sanitized_input['smtptipo'] = sanitize_text_field($input['smtptipo']);
			}

			if (isset($input['port'])) {
				$sanitized_input['port'] = intval($input['port']);
			}

			if (isset($input['maestro'])) {
				if(is_multisite()){
					$sites=get_sites();
					foreach($sites as $site){
						switch_to_blog($site->blog_id);
							update_option('segundoemail_options',$sanitized_input);
						restore_current_blog();
					}
				}
			}

			$this->message="si entro";
			if (isset($input['testbutton'])) {
				// Si se hace clic en el botón "Test Configuration", ejecuta la función de prueba
				if ($this->test_smtp_settings()){
					$this->message="<h3 style='color:green;'>Todo bien!<h3>";
					//echo "si ok";
					
				}else{
					$this->message="<h3 style='background-color:red;color:white;'>Revise la configuracion de SMTP!<h3>";
					//echo "no funciona";
				}
			}


			return $sanitized_input;
		}
		
		public function test_button_callback() {
			echo '<input type="submit" name="test_smtp" id="test_smtp" class="button button-secondary" value="Test Configuration">';
		}
		public function activo_field_callback() {
			$options = get_option('segundoemail_options');
			$checkd = isset($options['activo'])&&$options['activo']==1?"checked ":"";
			echo '<input type="checkbox" name="segundoemail_options[activo]" '.$checkd.'value="1">';
		}

		public function host_field_callback() {
			$options = get_option('segundoemail_options');
			echo '<input type="text" name="segundoemail_options[host]" value="' . esc_attr($options['host'] ?? '') . '">';
		}

		public function username_field_callback() {
			$options = get_option('segundoemail_options');
			echo '<input type="text" name="segundoemail_options[username]" value="' . esc_attr($options['username'] ?? '') . '">';
		}

		public function password_field_callback() {
			$options = get_option('segundoemail_options');
			echo '<input type="password" name="segundoemail_options[password]" value="' . esc_attr($options['password'] ?? '') . '">';
		}

		public function smtptipo_field_callback() {
			$options = get_option('segundoemail_options');
			$smtptipo = isset($options['smtptipo']) ? $options['smtptipo'] : '';
			echo '<select name="segundoemail_options[smtptipo]">
				<option value="ssl" ' . selected($smtptipo, 'ssl', false) . '>SSL</option>
				<option value="tls" ' . selected($smtptipo, 'tls', false) . '>TLS</option>
			</select>';
		}

		public function port_field_callback() {
			$options = get_option('segundoemail_options');
			echo '<input type="number" name="segundoemail_options[port]" value="' . esc_attr($options['port'] ?? '') . '">';
		}

		public function maestro_field_callback() {
			echo '<input type="checkbox" name="segundoemail_options[maestro]"  value="1">(Use this config for all sites.)';
		}
		function test_smtp_settings() {
			try {
				// Obtén la instancia de $phpmailer
				global $phpmailer;

				// ... Configuración SMTP aquí ...
				if (isset($input['host'])) {
					$phpmailer->Host = sanitize_text_field($input['host']);
				}
				if (isset($input['username'])) {
					$phpmailer->Username = sanitize_text_field($input['username']);
				}
				if (isset($input['password'])) {
					$phpmailer->Password = sanitize_text_field($input['password']);
				}
				if (isset($input['smtptipo'])) {
					$phpmailer->SMTPSecure = sanitize_text_field($input['smtptipo']);
				}
				if (isset($input['port'])) {
					$phpmailer->Port = intval($input['port']);
				}
				// Intenta enviar el correo
				if (!$phpmailer->Send()) {
					throw new Exception('No se pudo enviar el correo de prueba: ' . $phpmailer->ErrorInfo);
				}

				// Si llegamos aquí, el correo se envió correctamente
				return true;
			} catch (Exception $e) {
				// Captura cualquier excepción y maneja los errores
				//return $e->getMessage();
				return false;
			}
		}

		function correo2enviado($order){
			$order_id=$order->get_id();
			$email2 = get_post_meta($order_id,'email2sent',true)?"<span class='dashicons dashicons-yes' style='color:green;'></span>":"<span class='dashicons dashicons-no' style='color:red;'></span>";
			echo "<div style='background-color:#fff;border:solid #d7cad2 1px;border-radius:5px;padding:5px;margin-bottom:5px;width:98%'><i class='fas fa-envelope'></i>&nbsp;Se envio 2do correo por smtp alternativo?: ".$email2."</div>";
		}
	}

endif;
